#!/bin/bash
#
# Automate a headless MegaGlest game server
#
# The game server is always started for a single game only to rule out eventual
# side effects which may drain on system resources. Once the server is up and 
# running it will automatically try to publish to the masterserver. For this to
# work, Internet originated traffic must be able to reach the server on TCP
# port 61357. For FTP functionality (not currently supported on headless 
# servers) you also need to make Internet originated traffic on TCP ports 61358
# to 61366 reach the server.
# Once publishing to the master server succeeded (this can be verified at
# <http://master.megaglest.org>) you may connect to it from within your 
# Desktops' MegaGlest installation. The first user connecting to a headless
# server controls it. If this user disconnects, the next joining user takes
# control.
#

# Install location
DIR_GAME=~/megaglest

# Log file locations
LOG_SERVER=~/.megaglest/server.log


# ---

cd $DIR_GAME
ulimit -c unlimited

while true; do
  if [ -f "$LOG_SERVER" ]; then mv -f "$LOG_SERVER" "$LOG_SERVER.1"; fi
  date > "$LOG_SERVER"
  echo 'Starting server...' | tee -a "$LOG_SERVER"
  ./start_megaglest --ini-path=./ --data-path=./ --headless-server-mode=exit >> "$LOG_SERVER" 2>&1
  if [ $? -ne 0 ];
  then
    echo 'ERROR: Server has quit unexpectedly.' >> "$LOG_SERVER"
    echo 'ERROR: Server has quit unexpectedly.' >&2
    echo '       Please inspect '"$LOG_SERVER"'.' >&2
    exit 1
  else
    echo 'Server has quit.' | tee -a "$LOG_SERVER"
  fi
done
